"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _themeUi = require("theme-ui");

var _react = require("react");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _keyboard = require("../../utilities/keyboard");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/** @jsx jsx */
var Content = function Content(_ref) {
  var children = _ref.children,
      update = _ref.update,
      closeOnClick = _ref.closeOnClick,
      closeOnClickOutside = _ref.closeOnClickOutside,
      closeOnEsc = _ref.closeOnEsc,
      onClose = _ref.onClose;
  var element = (0, _react.useRef)(null);

  var _useKeys = (0, _keyboard.useKeys)(),
      isEscapePressed = _useKeys.isEscapePressed;

  var getContentDOM = function getContentDOM() {
    return element && element.current;
  };

  var handleOnClickInside = function handleOnClickInside(e) {
    if (getContentDOM().contains(e.target)) {
      onClose();
    }
  };

  var handleOnClickOutside = function handleOnClickOutside(e) {
    if (!getContentDOM().contains(e.target)) {
      onClose();
    }
  };

  var attachEvents = function attachEvents() {
    if (closeOnClick) {
      document.addEventListener('click', handleOnClickInside);
    }

    if (closeOnClickOutside) {
      document.addEventListener('click', handleOnClickOutside);
    }
  };

  var detachEvents = function detachEvents() {
    if (closeOnClick) {
      document.removeEventListener('click', handleOnClickInside);
    }

    if (closeOnClickOutside) {
      document.removeEventListener('click', handleOnClickOutside);
    }
  };

  (0, _react.useEffect)(function () {
    attachEvents();
    update();
    return detachEvents;
  }, []);

  if (closeOnEsc && isEscapePressed) {
    onClose();
  }

  return (0, _themeUi.jsx)("div", {
    ref: element
  }, children);
};

Content.propTypes = {
  children: _propTypes["default"].node,
  update: _propTypes["default"].func.isRequired,
  closeOnClick: _propTypes["default"].bool,
  closeOnClickOutside: _propTypes["default"].bool,
  closeOnEsc: _propTypes["default"].bool,
  onClose: _propTypes["default"].func.isRequired
};
var _default = Content;
exports["default"] = _default;