"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useKeys = exports.useKey = void 0;

var _react = require("react");

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(n); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var Keys = {
  Enter: {
    key: 'Enter',
    keyCode: 13
  },
  Space: {
    key: 'Space',
    keyCode: 32
  },
  Escape: {
    key: 'Escape',
    keyCode: 27
  },
  ArrowLeft: {
    key: 'ArrowLeft',
    keyCode: 37
  },
  ArrowRight: {
    key: 'ArrowRight',
    keyCode: 39
  },
  ArrowDown: {
    key: 'ArrowDown',
    keyCode: 40
  },
  ArrowUp: {
    key: 'ArrowUp',
    keyCode: 38
  },
  End: {
    key: 'End',
    keyCode: 35
  },
  Home: {
    key: 'Home',
    keyCode: 36
  }
};

var checkKey = function checkKey(e, name) {
  var Key = Keys[name];
  return e.key === Key.key || e.keyCode === Key.keyCode;
};

var isKeyFactory = function isKeyFactory(name) {
  return function (e) {
    return checkKey(e, name);
  };
};

var useKey = function useKey(name) {
  var isKey = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : isKeyFactory(name);

  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      keyPressed = _useState2[0],
      setKeyPressed = _useState2[1];

  var onKeyDown = function onKeyDown(e) {
    if (isKey(e)) {
      setKeyPressed(true);
    }
  };

  var onKeyUp = function onKeyUp(e) {
    if (isKey(e)) {
      setKeyPressed(false);
    }
  };

  (0, _react.useEffect)(function () {
    window.addEventListener('keydown', onKeyDown);
    window.addEventListener('keyup', onKeyUp);
    return function () {
      window.removeEventListener('keydown', onKeyDown);
      window.removeEventListener('keyup', onKeyUp);
    };
  }, []);
  return keyPressed;
};

exports.useKey = useKey;

var useKeys = function useKeys() {
  return {
    isEnterPressed: useKey('Enter'),
    isSpacePressed: useKey('Space'),
    isEscapePressed: useKey('Escape'),
    isLeftPressed: useKey('ArrowLeft'),
    isRightPressed: useKey('ArrowRight'),
    isDownPressed: useKey('ArrowDown'),
    isUpPressed: useKey('ArrowUp'),
    isHomePressed: useKey('Home'),
    isEndPressed: useKey('End')
  };
};

exports.useKeys = useKeys;