/** @jsx jsx */
import { useContext } from 'react'
import { jsx, Flex, Box, Text } from 'theme-ui'
import PropTypes from 'prop-types'
import { Field as Base, ErrorMessage } from 'formik'
import id from 'shortid'

import Input from '../Input'
import Error from '../Error'
import Hint from '../Hint'
import Label from '../Label'
import { GroupContext } from '../Group'

const InlineField = ({
  name,
  label,
  hint,
  component = Input.Text,
  placeholder,
  type,
  children,
  defaultChecked,
  value,
  ...props
}) => {
  const { inGroup } = useContext(GroupContext)
  const uuid = inGroup ? `${name}-${id.generate()}` : name
  return (
    <Flex sx={{ flexDirection: 'row', alignItems: 'center' }} mb={4} {...props}>
      <Box as="label" mb={0} htmlFor={uuid} sx={{ order: 1 }}>
        <Label as={Text}>{label}</Label>
        {hint && <Hint>{hint}</Hint>}
        {!inGroup && <ErrorMessage component={Error} name={name} />}
      </Box>
      <Box sx={{ order: 0 }}>
        <Base
          component={component}
          id={uuid}
          name={name}
          placeholder={placeholder}
          type={type}
          defaultChecked={defaultChecked}
          value={value}
        >
          {children}
        </Base>
      </Box>
    </Flex>
  )
}

const StackedField = ({
  name,
  label,
  hint,
  component = Input.Text,
  placeholder,
  type,
  children,
  defaultChecked,
  value,
  ...props
}) => (
  <Flex sx={{ flexDirection: 'column' }} mb={4} {...props}>
    <Box as="label" mb={2} htmlFor={name} sx={{ order: 0 }}>
      <Label as={Text}>{label}</Label>
      {hint && <Hint>{hint}</Hint>}
    </Box>
    <Box sx={{ order: 1 }}>
      <Base
        component={component}
        id={name}
        name={name}
        placeholder={placeholder}
        type={type}
        defaultChecked={defaultChecked}
        value={value}
      >
        {children}
      </Base>
    </Box>
  </Flex>
)

const Field = ({ inline = false, ...props }) => {
  return inline ? <InlineField {...props} /> : <StackedField {...props} />
}

Field.propTypes = {
  component: PropTypes.any,
  hint: PropTypes.string,
  label: PropTypes.string.isRequired,
  name: PropTypes.string,
  placeholder: PropTypes.string,
  type: PropTypes.string,
  children: PropTypes.node,
  inline: PropTypes.bool,
  defaultChecked: PropTypes.bool,
  value: PropTypes.string,
}

InlineField.propTypes = Field.PropTypes
StackedField.propTypes = Field.PropTypes

export default Field
