/** @jsx jsx */
import { jsx } from 'theme-ui'
import PropTypes from 'prop-types'
import { Formik } from 'formik'
import _size from 'lodash/size'

import Summary from '../Summary'

const Form = ({
  initialValues,
  onSubmit,
  summary = true,
  children,
  validate,
  validationSchema,
  ...props
}) => (
  <Formik
    initialValues={initialValues}
    onSubmit={onSubmit}
    validate={validate}
    validateOnBlur={false}
    validateOnChange={false}
    validationSchema={validationSchema}
  >
    {({ errors, handleSubmit }) => (
      <form {...props} noValidate onSubmit={handleSubmit}>
        {_size(errors) > 0 && summary && <Summary errors={errors} />}
        {children}
      </form>
    )}
  </Formik>
)

Form.propTypes = {
  children: PropTypes.node.isRequired,
  initialValues: PropTypes.object.isRequired,
  onSubmit: PropTypes.func.isRequired,
  summary: PropTypes.bool,
  validate: PropTypes.func,
  validationSchema: PropTypes.object,
}

export default Form
