/** @jsx jsx */
import { createContext } from 'react'
import PropTypes from 'prop-types'
import { jsx, Flex, Box } from 'theme-ui'
import { ErrorMessage } from 'formik'

import Label from '../Label'
import Hint from '../Hint'
import Error from '../Error'

export const GroupContext = createContext({ inGroup: false, name: '' })

const Group = ({
  children,
  name,
  label,
  hint,
  variant = 'default',
  inline = false,
  ...props
}) => {
  return (
    <GroupContext.Provider value={{ inGroup: true, name }}>
      <Flex
        as="fieldset"
        id={name}
        sx={{ flexDirection: 'column', variant: `forms.group.${variant}` }}
        {...props}
      >
        <Box mb={3}>
          {label && (
            <Label as="legend" p={0}>
              {label}
            </Label>
          )}
          {hint && <Hint>{hint}</Hint>}
          <ErrorMessage component={Error} name={name} />
        </Box>
        <Flex sx={{ flexDirection: inline ? ['column'] : ['column', 'row'] }}>
          {children}
        </Flex>
      </Flex>
    </GroupContext.Provider>
  )
}

Group.propTypes = {
  children: PropTypes.node,
  name: PropTypes.string.isRequired,
  label: PropTypes.string,
  hint: PropTypes.string,
  inline: PropTypes.bool,
  variant: PropTypes.string,
}

export default Group
