/** @jsx jsx */
import React from 'react'
import { jsx, Box } from 'theme-ui'
import PropTypes from 'prop-types'

const SVG = props => (
  <Box
    as="svg"
    xmlns="http://www.w3.org/2000/svg"
    width={24}
    height={24}
    viewBox="0 0 24 24"
    fill="currentcolor"
    {...props}
  />
)

const CheckboxChecked = props => (
  <SVG {...props}>
    <path d="M19 3H5c-1.11 0-2 .9-2 2v14c0 1.1.89 2 2 2h14c1.11 0 2-.9 2-2V5c0-1.1-.89-2-2-2zm-9 14l-5-5 1.41-1.41L10 14.17l7.59-7.59L19 8l-9 9z" />
  </SVG>
)

const CheckboxUnchecked = props => (
  <SVG {...props}>
    <path d="M19 5v14H5V5h14m0-2H5c-1.1 0-2 .9-2 2v14c0 1.1.9 2 2 2h14c1.1 0 2-.9 2-2V5c0-1.1-.9-2-2-2z" />
  </SVG>
)

const CheckboxIcon = props => (
  <React.Fragment>
    <CheckboxChecked
      {...props}
      __css={{
        display: 'none',
        'input:checked ~ &': {
          display: 'block',
        },
      }}
    />
    <CheckboxUnchecked
      {...props}
      __css={{
        display: 'block',
        'input:checked ~ &': {
          display: 'none',
        },
      }}
    />
  </React.Fragment>
)

const Checkbox = React.forwardRef(
  ({ field, sx, variant = 'checkbox', ...props }, ref) => (
    <Box>
      <Box
        ref={ref}
        as="input"
        {...props}
        {...field}
        type="checkbox"
        checked={field.value}
        sx={{
          position: 'absolute',
          opacity: 0,
          zIndex: 1,
          width: '24px',
          height: '24px',
          overflow: 'hidden',
        }}
      />
      <Box
        as={CheckboxIcon}
        aria-hidden="true"
        variant={variant}
        sx={sx}
        __css={{
          mr: 2,
          borderRadius: 4,
          color: 'gray',
          'input:checked ~ &': {
            color: 'primary',
          },
          'input:focus ~ &': {
            color: 'primary',
            bg: 'highlight',
          },
        }}
      />
    </Box>
  ),
)

Checkbox.propTypes = {
  field: PropTypes.object,
  variant: PropTypes.string,
}

export default Checkbox
