/** @jsx jsx */
import { jsx, Box, Text, Link } from 'theme-ui'
import { useRef, useEffect } from 'react'
import PropTypes from 'prop-types'
import _map from 'lodash/map'

const Summary = ({
  errors,
  variant = 'default',
  title = `Oops, there's a problem`,
}) => {
  const element = useRef(null)
  const id = 'ErrorSummary'

  useEffect(() => {
    element.current && element.current.focus()
  }, [])

  const handleOnClick = e => {
    e.preventDefault()
    const href = e.target.href
    const id = href.substring(href.indexOf('#') + 1, href.length)
    document.getElementById(id).focus()
  }

  return (
    <Box
      ref={element}
      mb={4}
      p={3}
      role="group"
      tabIndex="-1"
      aria-labelledby={`ErrorSummary-Heading-${id}`}
      sx={{ variant: `forms.summary.${variant}` }}
    >
      {title && (
        <Text as="h4" id={`ErrorSummary-Heading-${id}`} mb={2}>
          {title}
        </Text>
      )}
      <ul sx={{ m: 0, p: 0, listStyleType: 'none' }}>
        {_map(errors, (error, key) => (
          <li key={key}>
            <Link
              href={`#${key}`}
              onClick={handleOnClick}
              sx={{ color: 'muted' }}
            >
              {error}
            </Link>
          </li>
        ))}
      </ul>
    </Box>
  )
}

Summary.propTypes = {
  errors: PropTypes.object.isRequired,
  variant: PropTypes.string,
  title: PropTypes.string,
}

export default Summary
