/** @jsx jsx */
import { jsx, Box } from 'theme-ui'
import PropTypes from 'prop-types'

import Portal from '../Portal'
import Overlay from '../Overlay'

const propTypes = {
  isOpen: PropTypes.bool,
  onClose: PropTypes.func.isRequired,
  children: PropTypes.node,
  closeOnClickOutside: PropTypes.bool,
  overlay: PropTypes.bool,
}

const Layer = ({
  isOpen = false,
  onClose,
  children,
  closeOnClickOutside = true,
  overlay = true,
}) => {
  return isOpen ? (
    <Portal onClose={onClose}>
      <Box
        sx={{
          top: 0,
          bottom: 0,
          left: 0,
          right: 0,
          position: 'fixed',
          zIndex: 999,
        }}
      >
        <Overlay
          onClick={() => closeOnClickOutside && onClose()}
          overlay={overlay}
        />
        {children}
      </Box>
    </Portal>
  ) : null
}

Layer.propTypes = propTypes

export default Layer
