/** @jsx jsx */
import { jsx } from 'theme-ui'
import { useEffect, useRef } from 'react'
import PropTypes from 'prop-types'

import { useKeys } from '../../utilities/keyboard'

const Content = ({
  children,
  update,
  closeOnClick,
  closeOnClickOutside,
  closeOnEsc,
  onClose,
}) => {
  const element = useRef(null)
  const { isEscapePressed } = useKeys()

  const getContentDOM = () => element && element.current

  const handleOnClickInside = e => {
    if (getContentDOM().contains(e.target)) {
      onClose()
    }
  }

  const handleOnClickOutside = e => {
    if (!getContentDOM().contains(e.target)) {
      onClose()
    }
  }

  const attachEvents = () => {
    if (closeOnClick) {
      document.addEventListener('click', handleOnClickInside)
    }
    if (closeOnClickOutside) {
      document.addEventListener('click', handleOnClickOutside)
    }
  }

  const detachEvents = () => {
    if (closeOnClick) {
      document.removeEventListener('click', handleOnClickInside)
    }
    if (closeOnClickOutside) {
      document.removeEventListener('click', handleOnClickOutside)
    }
  }

  useEffect(() => {
    attachEvents()
    update()
    return detachEvents
  }, [])

  if (closeOnEsc && isEscapePressed) {
    onClose()
  }

  return <div ref={element}>{children}</div>
}

Content.propTypes = {
  children: PropTypes.node,
  update: PropTypes.func.isRequired,
  closeOnClick: PropTypes.bool,
  closeOnClickOutside: PropTypes.bool,
  closeOnEsc: PropTypes.bool,
  onClose: PropTypes.func.isRequired,
}

export default Content
