/** @jsx jsx */
import { jsx, Button, Box } from 'theme-ui'
import PropTypes from 'prop-types'
import { Manager, Reference, Popper } from 'react-popper'

import Content from './Content'

const Popover = ({
  isOpen,
  onClose,
  onOpen,
  children,
  closeOnClick = false,
  closeOnClickOutside = true,
  closeOnEsc = true,
}) => {
  const handleOnTargetClick = () => (isOpen ? onClose() : onOpen())
  return (
    <Manager>
      <Reference>
        {({ ref }) => (
          <Button onClick={handleOnTargetClick} ref={ref} variant="plain">
            {children[0]}
          </Button>
        )}
      </Reference>
      <Popper placement="bottom" positionFixed={true}>
        {({ ref, style, placement, arrowProps, scheduleUpdate }) => (
          <Box data-placement={placement} ref={ref} sx={style}>
            {isOpen && (
              <Content
                update={scheduleUpdate}
                onClose={onClose}
                closeOnClick={closeOnClick}
                closeOnClickOutside={closeOnClickOutside}
                closeOnEsc={closeOnEsc}
              >
                {children[1]}
              </Content>
            )}
            <div ref={arrowProps.ref} style={arrowProps.style} />
          </Box>
        )}
      </Popper>
    </Manager>
  )
}

Popover.propTypes = {
  isOpen: PropTypes.bool,
  onClose: PropTypes.func,
  onOpen: PropTypes.func,
  children: PropTypes.node.isRequired,
  placement: PropTypes.oneOf(['top', 'right', 'bottom', 'left']),
  closeOnClick: PropTypes.bool,
  closeOnClickOutside: PropTypes.bool,
  closeOnEsc: PropTypes.bool,
}

export default Popover
