import { tailwind } from '@theme-ui/presets'

const overlay = {
  top: 0,
  bottom: 0,
  left: 0,
  right: 0,
  position: 'fixed',
  zIndex: '40',
}

const modal = {
  position: 'relative',
  p: 3,
  zIndex: '50',
}

const input = {
  borderColor: 'gray',
  borderRadius: 0,
  fontFamily: 'inherit',
  ':focus': {
    outline: 'none',
    borderColor: 'primary',
  },
  ':invalid': {
    outline: 'none',
    borderColor: 'danger',
    boxShadow: 'none',
  },
}

export default {
  ...tailwind,
  useCustomProperties: true,
  colors: {
    ...tailwind.colors,
    background: 'transparent',
    text: 'rgba(0, 0, 0, 0.84)',
    primary: '#1FB6FF',
    secondary: '#3300CC',
    accent: '#C0CCDA',
    highlight: '',
    muted: '#F6F6F6',
    danger: '#FF4949',
    gray: '#C0CCDA',
  },
  sizes: {
    ...tailwind.sizes,
    container: 1600,
  },
  text: {
    error: {
      color: 'danger',
    },
    hint: {
      fontSize: 0,
      color: 'text',
    },
  },
  cards: {
    primary: {
      padding: 2,
      boxShadow: 'default',
    },
  },
  modals: {
    default: {
      ...modal,
      maxWidth: 600,
      width: ['full', '2/3'],
      backgroundColor: '#fff',
      mx: 'auto',
      my: [0, '5%'],
    },
    fullscreen: {
      ...modal,
      background: '#fff',
      minWidth: 'screenwidth',
      minHeight: 'screenHeight',
    },
  },
  overlays: {
    default: {
      ...overlay,
      backgroundColor: 'rgba(0,0,0,0.6)',
    },
    hidden: {
      ...overlay,
      backgroundColor: 'transparent',
    },
  },
  buttons: {
    primary: {
      ...tailwind.buttons.primary,
      cursor: 'pointer',
      ':disabled': {
        opacity: 0.4,
        cursor: 'default',
        pointerEvents: 'none',
      },
    },
    plain: {
      backgroundColor: 'transparent',
      color: 'inherit',
      p: 0,
      m: 0,
      cursor: 'pointer',
    },
  },
  images: {
    avatar: {
      width: '48px',
      height: '48px',
      borderRadius: 99999,
    },
  },
  forms: {
    input: {
      ...input,
    },
    textarea: {
      ...input,
    },
    select: {
      ...input,
    },
    label: {
      fontWeight: 'bold',
    },
    group: {
      default: {
        padding: 0,
        border: 'none',
      },
    },
    summary: {
      default: {
        backgroundColor: 'danger',
        color: 'muted',
      },
    },
  },
  styles: {
    ...tailwind.styles,
    root: {
      ...tailwind.styles.root,
      color: `text`,
      backgroundColor: `background`,
    },
    p: {
      fontSize: [1, 2],
      letterSpacing: `-0.003em`,
      lineHeight: `body`,
      '--baseline-multiplier': 0.179,
      '--x-height-multiplier': 0.35,
      color: `text`,
    },
    Container: {
      px: [3, 4],
      maxWidth: '1600px',
    },
  },
}
