import { useState, useEffect } from 'react'

const Keys = {
  Enter: {
    key: 'Enter',
    keyCode: 13,
  },
  Space: {
    key: 'Space',
    keyCode: 32,
  },
  Escape: {
    key: 'Escape',
    keyCode: 27,
  },
  ArrowLeft: {
    key: 'ArrowLeft',
    keyCode: 37,
  },
  ArrowRight: {
    key: 'ArrowRight',
    keyCode: 39,
  },
  ArrowDown: {
    key: 'ArrowDown',
    keyCode: 40,
  },
  ArrowUp: {
    key: 'ArrowUp',
    keyCode: 38,
  },
  End: {
    key: 'End',
    keyCode: 35,
  },
  Home: {
    key: 'Home',
    keyCode: 36,
  },
}

const checkKey = (e, name) => {
  const Key = Keys[name]
  return e.key === Key.key || e.keyCode === Key.keyCode
}

const isKeyFactory = name => {
  return e => {
    return checkKey(e, name)
  }
}

export const useKey = (name, isKey = isKeyFactory(name)) => {
  const [keyPressed, setKeyPressed] = useState(false)
  const onKeyDown = e => {
    if (isKey(e)) {
      setKeyPressed(true)
    }
  }
  const onKeyUp = e => {
    if (isKey(e)) {
      setKeyPressed(false)
    }
  }

  useEffect(() => {
    window.addEventListener('keydown', onKeyDown)
    window.addEventListener('keyup', onKeyUp)

    return () => {
      window.removeEventListener('keydown', onKeyDown)
      window.removeEventListener('keyup', onKeyUp)
    }
  }, [])

  return keyPressed
}

export const useKeys = () => {
  return {
    isEnterPressed: useKey('Enter'),
    isSpacePressed: useKey('Space'),
    isEscapePressed: useKey('Escape'),
    isLeftPressed: useKey('ArrowLeft'),
    isRightPressed: useKey('ArrowRight'),
    isDownPressed: useKey('ArrowDown'),
    isUpPressed: useKey('ArrowUp'),
    isHomePressed: useKey('Home'),
    isEndPressed: useKey('End'),
  }
}
