import React from 'react'
import * as Yup from 'yup'

import { Container, Form, Button } from '../../src'

const FormExample = () => {
  const handleOnSubmit = e => console.log(e)

  const initialValues = {
    name: 'Andrew',
    email: 'andrew@sul.io',
    phone: '2489339399',
    password: 'Test@123',
    type: 'Online Store',
    marketing: false,
    color: 'red',
  }

  const validationSchema = Yup.object().shape({
    name: Yup.string().required('Enter your first name'),
    email: Yup.string()
      .email('Your email address must contain an "at" symbol')
      .required('Enter your email address'),
    phone: Yup.number()
      .typeError('A phone number must be a number')
      .positive("A phone number can't start with a minus")
      .integer("A phone number can't include a decimal point"),
    marketing: Yup.boolean().required('Select a marketing value'),
  })

  return (
    <Container py={[3, 4]}>
      <Form
        onSubmit={handleOnSubmit}
        initialValues={initialValues}
        validationSchema={validationSchema}
      >
        <Form.Field name="name" label="First Name" />
        <Form.Field
          component={Form.Input.Email}
          hint="So we can follow up"
          label="Email Address"
          name="email"
        />
        <Form.Field
          name="budget"
          label="Budget"
          hint="So we can better tailor a solution for your project"
          placeholder="$5,000, $20,000, more?"
        />
        <Form.Field
          component={Form.Input.Number}
          hint="If you'd like us to call instead"
          label="Phone Number"
          name="phone"
        />
        <Form.Field
          component={Form.Input.Password}
          label="Password"
          name="password"
        />
        <Form.Field
          component={Form.Input.Textarea}
          hint="Write us a simple description of your project"
          label="Project"
          name="project"
        />
        <Form.Field
          component={Form.Input.Select}
          hint="Let us know what type of project you're looking for"
          label="Project Type"
          name="type"
        >
          <option>Website</option>
          <option>Online Store</option>
          <option>Mobile App</option>
        </Form.Field>
        <Form.Field
          component={Form.Input.Checkbox}
          name="marketing"
          label="Opt in to marketing"
          hint="Sign up to receive hints and tips"
          inline
          mr={3}
        />
        <Form.Group
          label="Favorite Colors"
          hint="Choose a favorite color"
          name="color"
        >
          <Form.Field
            component={Form.Input.Radio}
            name="color"
            label="Red"
            value="red"
            hint="A muted red indicating stop! stop! stop!"
            inline
            mr={3}
            defaultChecked={true}
          />
          <Form.Field
            component={Form.Input.Radio}
            name="color"
            label="Green"
            value="green"
            hint="A bright green indicating go! go! go!"
            inline
          />
        </Form.Group>
        <Button type="submit">Submit</Button>
      </Form>
    </Container>
  )
}

export default {
  title: 'Elements/Form',
  component: Form,
}

export const Default = () => <FormExample />
